=================
Beat the Bug Eyes
=================

You're trapped! Everywhere you turn you catch a glimpse of the steely cold
light of a space bug's eyes before it slithers down behind a rock again.
Slowly the bugs edge towards you, hemming you in, waiting for a chance to bind
you in their sticky web-like extrusions. Luckily you have your proton blaster
with you.

The bug eyes pop up in four different places on your screen and these
correspond to keys 1 to 4. Press the correct key while the bug's eyes are on
the screen and you will blast it. There are 10 bugs in all - the more you
blast, the greater your chance of escape.

The code
========

.. literalinclude:: beat_the_bug_eyes.py
   :language: python

How to change the speed
-----------------------

You can speed the game up by changing the length of time that you sleep
on line 90, or the timeout on line 119.

How to use more of the screen
-----------------------------

This program was written to fit on an 80x25 screen - the standard size for a
Unix terminal. Can you work out what you need to change to handle a larger or
smaller screen?

Puzzle corner
-------------

Can you change the program to make the bugs appear in more than four places on
the screen? Can you add more bugs too?
